extern crate imagefmt;

use std;

#[derive(PartialEq, Eq, Hash, Clone, Copy)]
pub struct PixelRGBA<T> {
	pub r: T,
	pub g: T,
	pub b: T,
	pub a: T
}

pub struct Image {
	pub width: usize,
	pub height: usize,
	pub pixels: Vec<PixelRGBA<u8>>
}

impl Image {
	pub fn new(path: &str) -> Result<Image, std::io::Error> {
		let img = try!(
			imagefmt::read( path, imagefmt::ColFmt::RGBA )
			.map_err( |_| std::io::Error::new(
				std::io::ErrorKind::Other,
				format!( "Could not open image" )
			) )
		);

		let mut image = Image {
			width: img.w,
			height: img.h,
			pixels: Vec::with_capacity( img.buf.len()/4 )
		};

		for i in 0..img.buf.len()/4 {
			image.pixels.push(
				PixelRGBA {
					r: img.buf[4*i+0],
					g: img.buf[4*i+1],
					b: img.buf[4*i+2],
					a: img.buf[4*i+3],
				}
			);
		}

		Ok(image)
	}
}

