use vector::*;

type Vector3f = Vector3<f32>;

pub fn cross_product(u: &Vector3f, v: &Vector3f) -> Vector3f {
	Vector3f {
		v: [
			u.v[1] * v.v[2] - u.v[2] * v.v[1],
			u.v[2] * v.v[0] - u.v[0] * v.v[2],
			u.v[0] * v.v[1] - u.v[1] * v.v[0]
		]
	}
}

pub fn normalize_vector(v: &Vector3f) -> Vector3f {
	let length = ( v.v[0] * v.v[0] + v.v[1] * v.v[1] + v.v[2] * v.v[2] ).sqrt();

	Vector3f {
		v: [
			v.v[0] / length,
			v.v[1] / length,
			v.v[2] / length
		]
	}
}

pub fn add_vec(u: &Vector3f, v: &Vector3f) -> Vector3f {
	Vector3f {
		v: [
			u.v[0] + v.v[0],
			u.v[1] + v.v[1],
			u.v[2] + v.v[2]
		]
	}	
}

pub fn sub_vec(u: &Vector3f, v: &Vector3f) -> Vector3f {
	Vector3f {
		v: [
			u.v[0] - v.v[0],
			u.v[1] - v.v[1],
			u.v[2] - v.v[2]
		]
	}	
}

pub fn scale_uniformly_vec(v: &Vector3f, s: f32) -> Vector3f {
	Vector3f {
		v: [
			s * v.v[0],
			s * v.v[1],
			s * v.v[2]
		]
	}	
}

